@@ -26,12 +26,13 @@ pub mod decoding;
 pub mod encoding;
 
 mod repeated;
-pub use repeated::Repeated;
+pub use repeated::*;
 
 mod varint;
 pub use varint::VarInt;
 
 mod map;
+pub use map::Map;
 
 #[cfg(test)]
 pub mod tests;
